pub struct FederationTest {
configs: BTreeMap<PeerId, ServerConfig>,
server_init: ServerModuleInitRegistry,
client_init: ClientModuleInitRegistry,
_task: TaskGroup,
num_peers: u16,
num_offline: u16,
connectors: ConnectorRegistry,
}Expand description
Test fixture for a running fedimint federation
Fields
configs: BTreeMap<PeerId, ServerConfig>server_init: ServerModuleInitRegistryclient_init: ClientModuleInitRegistry_task: TaskGroupnum_peers: u16num_offline: u16connectors: ConnectorRegistryImplementations
Sourceimpl FederationTest
impl FederationTest
Sourcepub async fn two_clients(&self) -> (ClientHandleArc, ClientHandleArc)
pub async fn two_clients(&self) -> (ClientHandleArc, ClientHandleArc)
Create two clients, useful for send/receive tests
Sourcepub async fn new_client(&self) -> ClientHandleArc
pub async fn new_client(&self) -> ClientHandleArc
Create a client connected to this fed
Sourcepub async fn new_client_rocksdb(&self) -> ClientHandleArc
pub async fn new_client_rocksdb(&self) -> ClientHandleArc
Create a client connected to this fed but using RocksDB instead of MemDB
Sourcepub async fn new_admin_api(&self, peer_id: PeerId) -> Result<DynGlobalApi>
pub async fn new_admin_api(&self, peer_id: PeerId) -> Result<DynGlobalApi>
Create a new admin api for the given PeerId
Sourcepub async fn new_admin_client(
&self,
peer_id: PeerId,
auth: ApiAuth,
) -> ClientHandleArc
pub async fn new_admin_client( &self, peer_id: PeerId, auth: ApiAuth, ) -> ClientHandleArc
Create a new admin client connected to this fed
pub async fn new_client_with( &self, client_config: ClientConfig, db: Database, admin_creds: Option<AdminCreds>, ) -> ClientHandleArc
Sourcepub async fn join_client_with_db(
&self,
db: Database,
root_secret: RootSecret,
) -> ClientHandleArc
pub async fn join_client_with_db( &self, db: Database, root_secret: RootSecret, ) -> ClientHandleArc
Join a federation with an existing database and root secret
Sourcepub async fn recover_client_with_db(
&self,
db: Database,
root_secret: RootSecret,
) -> ClientHandleArc
pub async fn recover_client_with_db( &self, db: Database, root_secret: RootSecret, ) -> ClientHandleArc
Create a recovering client with an existing database and root secret. Returns both the client and the database so a new client can be created with the same DB after recovery completes.
Sourcepub async fn open_client_with_db(
&self,
db: Database,
root_secret: RootSecret,
) -> ClientHandleArc
pub async fn open_client_with_db( &self, db: Database, root_secret: RootSecret, ) -> ClientHandleArc
Open an existing client database (e.g., after recovery)
Sourcepub fn invite_code(&self) -> InviteCode
pub fn invite_code(&self) -> InviteCode
Return first invite code for gateways
Sourcepub fn id(&self) -> FederationId
pub fn id(&self) -> FederationId
Return the federation id
Sourcepub async fn connect_gateway(&self, gw: &Gateway)
pub async fn connect_gateway(&self, gw: &Gateway)
Connects a gateway to this FederationTest
Sourcepub fn online_peer_ids(&self) -> impl Iterator<Item = PeerId> + use<>
pub fn online_peer_ids(&self) -> impl Iterator<Item = PeerId> + use<>
Return all online PeerIds
Sourcepub fn is_degraded(&self) -> bool
pub fn is_degraded(&self) -> bool
Returns true if the federation is running in a degraded state